==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/register.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_activation_success'=>'Dein Benutzerkonto wurde aktiviert. Du kannst dich nun anmelden.',
'account_successfully_created'=>'Das neue Konto wurde angelegt.',
'account_successfully_registered'=>'Dein Benutzerkonto wurde angelegt und die E-Mail versendet.',
'already_activated'=>'Dieses Konto ist bereits aktiviert und zur Nutzung bereit!',
'decline'=>'Ablehnen',
'explain_mail'=>'Du mußt hier eine gültige E-Mail Adresse angeben. Nach der Registrierung wirst du eine Mail mit weiteren Anweisungen und dein Kennwort erhalten. Es ist möglich, obschon nicht empfohlen, eine Wegwerfadresse zu benutzen, da du dein Konto später auch ohne E-Mail Adresse benutzen kannst.',
'explain_username'=>'Du mußt einen Benutzernamen für dein Konto aussuchen. Dieser muß mindestens drei Zeichen lang sein, darf aber dine Länge von zweiunddreißig (32) nicht überschreiten. Jegliche Buchstaben, Zahlen oder Spezialzeichen sind erlaubt mit Ausnahme eines numerischen Namens.',
'hash_not_equal'=>'Die Aktivierungserlaubnis ist nicht korrekt!',
'invalid_mail'=>'Du hast keine gültige E-Mail Adresse angegeben!',
'invalid_username'=>'Dein Benutzername ist nicht gültig!',
'register_account'=>'Ein Benutzerkonto registrieren',
'terms_of_use'=>'Unsere Nutzungsbedingungen',
'time_limit_exceeded'=>'Das Zeitfenster zur Aktivierung wurde überschritten!',
'username_already_used'=>'Dieser Benutzername wird bereits verwendet. Bitte nimm einen anderen!'
);
?>

==> larus_board-1.2.0.zip: larus_board-1.2.0/lb_private/lang/de/register.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_activation_success'=>'Dein Benutzerkonto wurde aktiviert. Du kannst dich nun anmelden.',
'account_successfully_created'=>'Das neue Konto wurde angelegt.',
'account_successfully_registered'=>'Dein Benutzerkonto wurde angelegt und die E-Mail versendet.',
'already_activated'=>'Dieses Konto ist bereits aktiviert und zur Nutzung bereit!',
'decline'=>'Ablehnen',
'explain_mail'=>'Du mußt hier eine gültige E-Mail Adresse angeben. Nach der Registrierung wirst du eine Mail mit weiteren Anweisungen erhalten. Es ist möglich, obschon nicht empfohlen, eine Wegwerfadresse zu benutzen, da du dein Konto später auch ohne E-Mail Adresse benutzen kannst.',
'explain_username'=>'Du mußt einen Benutzernamen für dein Konto aussuchen. Dieser muß mindestens drei Zeichen lang sein, darf aber eine Länge von zweiunddreißig (32) nicht überschreiten. Jegliche Buchstaben, Zahlen oder Spezialzeichen sind erlaubt mit Ausnahme eines numerischen Namens.',
'hash_not_equal'=>'Die Aktivierungserlaubnis ist nicht korrekt!',
'invalid_username'=>'Dein Benutzername ist nicht gültig!',
'register_account'=>'Ein Benutzerkonto registrieren',
'terms_of_use'=>'Unsere Nutzungsbedingungen',
'time_limit_exceeded'=>'Das Zeitfenster zur Aktivierung wurde überschritten!',
'username_already_used'=>'Dieser Benutzername wird bereits verwendet. Bitte nimm einen anderen!'
);
?>
